==> blackduck-common-api-2019.6.0.8-sources.jar: com/synopsys/integration/blackduck/api/manual/component/VulnerabilitySourceQualifiedId.java <==
/**
 * blackduck-common-api
 *
 * Copyright (c) 2019 Synopsys, Inc.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.synopsys.integration.blackduck.api.manual.component;

import com.synopsys.integration.blackduck.api.core.BlackDuckComponent;

public class VulnerabilitySourceQualifiedId extends BlackDuckComponent {
    private String source;
    private String vulnerabilityId;
    private String vulnerability;
    private String relatedVulnerabilityId;
    private String relatedVulnerability;

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getVulnerabilityId() {
        return vulnerabilityId;
    }

    public void setVulnerabilityId(String vulnerabilityId) {
        this.vulnerabilityId = vulnerabilityId;
    }

    public String getVulnerability() {
        return vulnerability;
    }

    public void setVulnerability(String vulnerability) {
        this.vulnerability = vulnerability;
    }

    public String getRelatedVulnerabilityId() {
        return relatedVulnerabilityId;
    }

    public void setRelatedVulnerabilityId(String relatedVulnerabilityId) {
        this.relatedVulnerabilityId = relatedVulnerabilityId;
    }

    public String getRelatedVulnerability() {
        return relatedVulnerability;
    }

    public void setRelatedVulnerability(String relatedVulnerability) {
        this.relatedVulnerability = relatedVulnerability;
    }

}

==> blackduck-common-api-2020.8.0.14-sources.jar: com/synopsys/integration/blackduck/api/manual/component/VulnerabilitySourceQualifiedId.java <==
/*
 * blackduck-common-api
 *
 * Copyright (c) 2021 Synopsys, Inc.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.synopsys.integration.blackduck.api.manual.component;

import com.synopsys.integration.blackduck.api.core.BlackDuckComponent;

public class VulnerabilitySourceQualifiedId extends BlackDuckComponent {
    private String source;
    private String vulnerabilityId;
    private String vulnerability;
    private String relatedVulnerabilityId;
    private String relatedVulnerability;
    private String severity;

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getVulnerabilityId() {
        return vulnerabilityId;
    }

    public void setVulnerabilityId(String vulnerabilityId) {
        this.vulnerabilityId = vulnerabilityId;
    }

    public String getVulnerability() {
        return vulnerability;
    }

    public void setVulnerability(String vulnerability) {
        this.vulnerability = vulnerability;
    }

    public String getRelatedVulnerabilityId() {
        return relatedVulnerabilityId;
    }

    public void setRelatedVulnerabilityId(String relatedVulnerabilityId) {
        this.relatedVulnerabilityId = relatedVulnerabilityId;
    }

    public String getRelatedVulnerability() {
        return relatedVulnerability;
    }

    public void setRelatedVulnerability(String relatedVulnerability) {
        this.relatedVulnerability = relatedVulnerability;
    }

    public String getSeverity() {
        return severity;
    }

    public void setSeverity(final String severity) {
        this.severity = severity;
    }
}
